@@ -255,7 +255,7 @@ as_cache_get_locale (AsCache *cache)
 /**
  * as_cache_set_locale:
  * @cache: an #AsCache instance.
- * @locale: the locale name.
+ * @locale: the locale in BCP47 format.
  *
  * Set the cache locale.
  */
@@ -1575,6 +1575,66 @@ as_cache_query_components (AsCache *cache,
 	return as_query_context_retrieve_components (qctx);
 }
 
+/**
+ * as_cache_is_empty:
+ * @cache: An instance of #AsCache.
+ *
+ * Test if the cache is empty.
+ *
+ * Returns: %TRUE if the cache is empty, %FALSE otherwise.
+ */
+gboolean
+as_cache_is_empty (AsCache* cache)
+{
+	AsCachePrivate *priv = GET_PRIVATE (cache);
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_reader_locker_new (&priv->rw_lock);
+
+	for (guint i = 0; i < priv->sections->len; i++) {
+		g_autoptr(XbNode) node = NULL;
+		g_autoptr(XbNode) child = NULL;
+		AsCacheSection *csec = (AsCacheSection*) g_ptr_array_index (priv->sections, i);
+
+		node = xb_silo_get_root (csec->silo);
+		child = xb_node_get_child (node);
+		if (child != NULL)
+			return FALSE;
+	}
+
+	return TRUE;
+}
+
+/**
+ * as_cache_get_component_count:
+ * @cache: An instance of #AsCache.
+ *
+ * Get the number of components present in this cache.
+ *
+ * Returns: The number of components present in the cache.
+ */
+guint
+as_cache_get_component_count (AsCache* cache)
+{
+	AsCachePrivate *priv = GET_PRIVATE (cache);
+	guint cpt_node_count = 0;
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_reader_locker_new (&priv->rw_lock);
+
+	for (guint i = 0; i < priv->sections->len; i++) {
+		g_autoptr(XbNode) n = NULL;
+		g_autoptr(XbNode) node = NULL;
+		AsCacheSection *csec = (AsCacheSection*) g_ptr_array_index (priv->sections, i);
+
+		node = xb_silo_get_root (csec->silo);
+		n = xb_node_get_child (node);
+		while (n != NULL) {
+			cpt_node_count++;
+			g_object_unref (n);
+			n = xb_node_get_next(n);
+		}
+	}
+
+	return cpt_node_count;
+}
+
 /**
  * as_cache_get_components_all:
  * @cache: An instance of #AsCache.
