@@ -39,14 +39,14 @@
 #include "as-utils-private.h"
 
 typedef struct {
-	gchar *id;
+	gchar			*id;
 	AsContentRatingValue	 value;
 } AsContentRatingKey;
 
 typedef struct
 {
-	gchar *kind;
-	GPtrArray *keys; /* of AsContentRatingKey */
+	gchar		*kind;
+	GPtrArray	*keys; /* of AsContentRatingKey */
 } AsContentRatingPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (AsContentRating, as_content_rating, G_TYPE_OBJECT)
@@ -613,7 +613,7 @@ as_content_rating_system_get_csm_ages (AsContentRatingSystem system, gsize *leng
 
 /*
  * parse_locale:
- * @locale: (transfer full): a locale to parse
+ * @locale: (transfer full): a POSIX locale to parse
  * @language_out: (out) (optional) (nullable): return location for the parsed
  *    language, or %NULL to ignore
  * @territory_out: (out) (optional) (nullable): return location for the parsed
@@ -646,6 +646,7 @@ parse_locale (gchar *locale  /* (transfer full) */,
 {
 	gchar *separator;
 	const gchar *language = NULL, *territory = NULL, *codeset = NULL, *modifier = NULL;
+	g_return_val_if_fail (locale, FALSE);
 
 	separator = strrchr (locale, '@');
 	if (separator != NULL) {
