@@ -870,6 +870,12 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The release timestamp is invalid."),
 	},
 
+	{ "release-description-outside-tag",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("The release description must be put inside a `description` tag"),
+	},
+
 	{ "artifact-type-invalid",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
