@@ -18,27 +18,26 @@ dnf --assumeyes --quiet --setopt=install_weak_deps=False install \
     gettext \
     gperf \
     gtk-doc \
-    intltool \
     itstool \
     libasan \
     libstemmer-devel \
     libubsan \
+    'pkgconfig(gio-2.0)' \
+    'pkgconfig(gobject-introspection-1.0)' \
+    'pkgconfig(xmlb)' \
+    'pkgconfig(libxml-2.0)' \
+    'pkgconfig(yaml-0.1)' \
+    'pkgconfig(libcurl)' \
+    'pkgconfig(libsystemd)' \
+    'pkgconfig(librsvg-2.0)' \
+    'pkgconfig(libzstd)' \
     'pkgconfig(cairo)' \
     'pkgconfig(freetype2)' \
     'pkgconfig(fontconfig)' \
     'pkgconfig(gdk-pixbuf-2.0)' \
-    'pkgconfig(gio-2.0)' \
-    'pkgconfig(gobject-introspection-1.0)' \
-    'pkgconfig(libcurl)' \
-    'pkgconfig(librsvg-2.0)' \
-    'pkgconfig(libxml-2.0)' \
-    'pkgconfig(xmlb)' \
-    'pkgconfig(packagekit-glib2)' \
     'pkgconfig(pango)' \
-    'pkgconfig(protobuf-lite)' \
     'pkgconfig(Qt5Core)' \
     qt5-linguist \
-    'pkgconfig(yaml-0.1)' \
     sed \
     vala \
     xmlto
